@@ -1,9 +1,9 @@
-from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
+import logging
+
 from ocp_resources.resource import NamespacedResource
 
 
-LOGGER = get_logger(name=__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class CatalogSource(NamespacedResource):
@@ -11,24 +11,17 @@ class CatalogSource(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
+        name,
+        namespace,
         client=None,
         source_type=None,
         image=None,
         display_name=None,
         publisher=None,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.source_type = source_type
         self.image = image
@@ -37,9 +30,6 @@ class CatalogSource(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         res.update(
             {
                 "spec": {
