@@ -1,4 +1,3 @@
-from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
 
 
@@ -11,10 +10,10 @@ class MachineHealthCheck(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
-        cluster_name=None,
-        machineset_name=None,
+        name,
+        namespace,
+        cluster_name,
+        machineset_name,
         client=None,
         machine_role="worker",
         machine_type="worker",
@@ -23,16 +22,9 @@ class MachineHealthCheck(NamespacedResource):
         unhealthy_timeout="300s",
         reboot_strategy=False,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.cluster_name = cluster_name
         self.machineset_name = machineset_name
@@ -45,9 +37,6 @@ class MachineHealthCheck(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         if self.reboot_strategy:
             res["metadata"]["annotations"] = {
                 f"{self.api_group}/remediation-strategy": "external-baremetal"
