@@ -1,4 +1,4 @@
-from ocp_resources.resource import Resource
+from ocp_resources.resource import NamespacedResource, Resource
 
 
 class Node(Resource):
@@ -8,7 +8,7 @@ class Node(Resource):
 
     api_version = Resource.ApiVersion.V1
 
-    class Status(Resource.Status):
+    class Status(NamespacedResource.Status):
         READY = "Ready"
         SCHEDULING_DISABLED = "Ready,SchedulingDisabled"
 
@@ -34,7 +34,3 @@ class Node(Resource):
         for addr in self.instance.status.addresses:
             if addr.type == "InternalIP":
                 return addr.address
-
-    @property
-    def hostname(self):
-        return self.labels["kubernetes.io/hostname"]
