@@ -8,4 +8,4 @@ class ReplicaSet(NamespacedResource):
     OpenShift Service object.
     """
 
-    api_group = NamespacedResource.ApiGroup.APPS
+    api_version = NamespacedResource.ApiVersion.V1
